Tervetuloa Kirkko Cafeeseen!
Kirjoita /apua jos tarvitset lisää ohjeita chattailyyn.
Älä anna koskaan henkilökohtaisia tietojasi (nimeä, puhelinnumeroa) chatissä.
hundmåt => Mont Everest: sanoin että synti on näkökantakysymys... siis toisen synti voi olla toiselle hyve koska asiat määritellään eri tavalla eri kulttuureissa
Mont Everest: Jeesus ristiinnaulittiin juuri sen takia, että Hän sanoi itseään Jumalaksi, ja se oli papeille (!) liikaa.
Pakana . => Mont Everest: Tai Jeesusta pidettiin jumalana
Pakana . => Mont Everest: Tuntuu vähän että jos tosiaan on senkin verran fiksu ja totuutta kunnioittava ihminen kuin jeesus olisi saattanut olla tajutessaan sen minkä oli tajunnut ettei korottaisi itseään jumalaksi
Mont Everest => hundmåt: Synti-kysymystä täytykin katsoa Jumalan Sanan näkövinkkelistä, punnita asiat Sanalla.
-SIMO-: hahahaa
Da Tishbyte: eiks jeesus sanonu olevansa jumalan poika
hundmåt => Mont Everest: siis mie punnitan asiat neutraalista näkökulmasta
-SIMO-: tuliko paskat housuun häh?
hundmåt => Mont Everest: ja en ole kristitty nii miksi mie raamatulla punnittaisin mitään
rane28 liittyy keskusteluun. Hän on chattäillyt 287 minuutin ajan..
Finlandia: Terve
UsKoVa93 poistui keskustelusta
-SIMO-: pellet
Mont Everest => Pakana .: Jeesus on Jumala. Minun Herrani ja minun Jumalani.
Pakana . => Mont Everest: jeesus on saattanut olla joku hieman fiksumpi ihminen joka ollaan väritetty jumalaksi
rane28: iltaa
Finlandia: taas sitten tällainen yhdistetty uskonto ja häirikköilta?
Finlandia: iltaa
Pakana . => Mont Everest: ja jos on ollut niin fiksu mitä raamattu antaa ymmärtää niin tuskin on jumalaksi itseään korottanut
rane28: toni rantalaa näkyny?
Tahko: " kaikki joka ei ole uskosta on synti "
rane28: intoilijat
-SIMO- => Tahko: oosää idiootti vaa hiljaa!
hundmåt => Pakana .: miksei olisi
hundmåt => Pakana .: sehä o yleistä näillä kulttien johtajahahmoilla
hundmåt => Pakana .: kute nykyäänkin hyvin näkee
Pakana . => hundmåt: en usko että niin fiksu olisi itseään jumalaksi korottanut
UsKoVa-93 poistui keskustelusta
Mont Everest: PÄÄSIÄISEN SANOMA KUULUU: JEESUS ON NOUSSUT KUOLLEISTA! Hän elää ja tulee pian noutamaan omansa taivaan kotiin kuninkaallisiin häihin. Silloin täällä maan päällä alkaa suuri ahdistuksen aika!
Finlandia: taas näitä Simoja....
rane28: miten käy raamatun mukaan jos tappaa itsensä?
Pakana . => hundmåt: luulen että hänet on jälkikäteen korotettu jumalaksi
hundmåt => Pakana .: no onha noista kulttijohtajista moni erittäin älykkäitä ihmisiä mutta korottavat itsensä jumalaksi koska seuraajat eivät kyseenalaista
Pakana . => hundmåt: varmaankin
Kärpässieni poistuu paikalta: liian pitkään keskustelematta.
Finlandia: helvetillä pelottelijat
rane28: jep
Kärpässieni: Johan on markkinat taas.
Pakana . => hundmåt: tuli vaan tuosta eilisestä gandhi ohjelmasta mieleen että on saattanut olla sellainen gandhin tapainen valaistuja
Mont Everest: Merkkejä tästä kaikesta on havaittavissa!
Kärpässieni: PItäisköhän minun lähteä kiltisti nukkumaan perhana vieköön.
Finlandia: kuten mitä?
rane28: kukaan ei valitse tänne tulemista
Pakana . => hundmåt: ja tilannekkin on ollut sama, miehitetty israel ja miehitetty intia
Kärpässieni: Päätäni särkee perkeleet.
hundmåt => Pakana .: no jessestä paha sanoa ku siitä ole infoa juri
Pakana . => hundmåt: ja sama periaate että pitää hyvällä, ilman kostoa ym selvittää asiat
rane28: v kantaa
repe. => Pakana .: pa-paha kana -kana
Kärpässieni: Voihan sietana sumpare nyt .
Da Tishbyte: joo ei kande olla tääl ku jeesus tulee hakee sen posset
Pakana . => hundmåt: no ei ole mutta voisi helpolla kuvitella
Finlandia: paskapuhetta
Mont Everest => rane28: Murhamies ei ole Isää näkevä, sanoo Raamattu. Jää vain sitten arvailuksi, miten on käynyt, jos viime henkäisyllään onkin turvautunut Jeesukseen ja pelastunut, niinkuin toinen ryöväri ristillä.
Finlandia: tuota on jauhettu jo melkein 2000 vuotta
Hikkis liittyy keskusteluun
Hikkis:
Jumprahuiti poistui keskustelusta
rane28: kiitti
-SIMO-: dhhudfuifhffe
-SIMO-: duueeyue
-SIMO-: erfgrgreugfrt
-SIMO-: 5th45ty58
-SIMO-: sori
-SIMO-:
hundmåt => Mont Everest: puuh mie ole ikuna uskonu ja ns. kuolinvuoteella tullu edes mieleenkään rukoilla
hundmåt => Mont Everest: ja silti miusta mikää roisto tullut :D
Tuomas 1/12 liittyy keskusteluun
rane28: mut jos uskoo mutta ei kertakaikkiaan jaksa enää?
azrial poistuu paikalta: liian pitkään keskustelematta.
Hikkis: naiset on tänään pois täältä
Juoppo_ liittyy keskusteluun
Uskonveli. liittyy keskusteluun
Mont Everest => rane28: Ne asiat ovat onneksi Jumalan kädessä. Muutoin moni nääntyisi suruunsa, ellei sitä toivoa olisi!
Tuomas 1/12: iltaa
-SIMO-: MOI MOI MOI MOIMOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI M MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Uskonveli.: Rauhan tervehdys
Juoppo_: Hetkinen...
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Miksei ole naisia?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Hikkis:
Da Tishbyte: hund jos sä et usko hyvään etkä pahaan ni ethän sä voi tunnistaa niitä ja mistä sä tiiät ootko tehny kuinka hyvii juttuja tai kuinka pahoi
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tahko poistuu paikalta: liian pitkään keskustelematta.
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Hikkis:
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: lopeta!!!!!!!!!!!!!!!!!!!!!!!
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Hikkis:
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Uskonveli.: paina nimen vieressä olevasta ruksista
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: kuulitko
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova liittyy keskusteluun. Hän on chattäillyt 5917 minuutin ajan..
rane28: v**** moi
Finlandia: taas tätä....
Uskonveli. => uskova: Jumalan rauhaa
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Pakana . => hundmåt: on helppo kuvitella että sellainen olisi herättänyt huomiota ja jotkut ovat sitten innostuneet niin että tuo on varmaan messias
Finlandia poistuu paikalta: En jaksa.....
Olet tauolla, sano jotain jatkaaksesi.
Tuomas 1/12 => uskova: olen kuullut tästä, mutta nyt vasta näen
rane28: ookko sairaampi ku mä
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Mont Everest => hundmåt: Et koiranmuona lukenut, kun kirjoitin erään kuolinvuoteella pelastuneen tapauksesta?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Mitäs sanoisitte, jos ottasin tässä muutamat oluet ja lähtisin baariin??
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Pakana . => hundmåt: varmaan ollut itse vaatimaton ja hyvinkin askeettinen
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova => Uskonveli.: Rauhaa
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Autolla
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12 => Finlandia: kutsuitko simon tänne?
Hikkis poistui keskustelusta
Finlandia => Tuomas 1/12: en todellakaan
Uskonveli.: nimen vieressä on raksi, siitä painamalla voi hiljentää keskustelijan
uskova => Tuomas 1/12: siis mitä tapahtuu
Finlandia => Tuomas 1/12: lieneekö oikea Simo
Pakana . => hundmåt: jotkut uskonut väkisin että hän on jumala vaikka on itse kieltänyt sen ja siksi ristiinnaulittukkin
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12 => -SIMO-: rauhaa rakas
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Ette sano mtn?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: ookko sä noin tyhymä?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: jee jätkä leikkii
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12: ruks
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Mont Everest => hundmåt: Hän eli kapakkamaailmassa elämänsä, joi ja rellesti, huorasi ja vähät välitti Jumalasta. Kun joutui kuolinvuoteeseen, huusi tuskissaan apua, soitti puolisolleni, että tuu heti tänne! Ja kun sai kuulla
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Uskonveli.: uskovien yhteyden häirinnästä en tykkää
Finlandia => -SIMO-: *ruks*
-SIMO-: SENKIN PELLET
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
repe. poistuu paikalta: liian pitkään keskustelematta.
rane28: mee tarhaan
Kärpässieni poistuu paikalta: liian pitkään keskustelematta.
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Mont Everest => hundmåt: Jeesuksesta, otti Hänet heti vastaan: Ette voi kuvitella sitä iloa ja rauhaa. Sanoi olevansa maailman onnellisin mies, eikä sitten kyllä hävennyt Jeesusta!!!
Uskonveli.: ug ookko täällä jollain sananikillä?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova => -SIMO-: Jeesuksen nimessä lopeta
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12 => Finlandia: Mä vähän ymmärrän mitä puhuit..
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: en mäkään mikään uskon intoilija ,mut heittäkää toi pihalle
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
hundmåt => Mont Everest: nii siis kuka sanoi
Finlandia: ruksein jo sen
repe.:
Uskonveli.: ei täällä oo seriffiä paikalla
Finlandia => Tuomas 1/12: ruksein jo sen
Juoppo_: Ettekö oikeesti sano mtn tohon?
-SIMO-: BÖÖRTIIUTG
Pakana .: Kaikki privassa floodaamaan simolle takaisin
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova: Jeesus on paikalla
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Kärpässieni poistui keskustelusta
Finlandia: ihme tapa toivottaa päivää tuollakin
uskova => -SIMO-: Jeesus katso tämän ihmisen puoleen
Uskonveli.: Jeesus elää
Juoppo_: Ei sitte, heippa -->
Tuomas 1/12 => Pakana .: luuletko että siitä on iloa
-SIMO-: Toivotin päivää!
Finlandia: erikoinen tapa toivottaa
uskova => -SIMO-: päivää sullekin
Uskonveli.: \0/ \0/
Juoppo_ poistui keskustelusta
Pakana . => Tuomas 1/12: No ei välttämättä iloa
rane28: no älä sitten ota itsees
repe.: jumala sanoo sulle simo henkilökohtaisesti jos et lopeta pelleilyä annan sulle halvauksen
Da Tishbyte poistuu paikalta: liian pitkään keskustelematta.
Tuomas 1/12 => -SIMO-: Jeesus kuulee pienimmänkin avunhuudon
uskova => -SIMO-: Jeesukselle olet rakas
-SIMO- poistui keskustelusta
Finlandia: olikohan tuo edes oikea Simo
Uskonveli.: meinaatko että häiriköitäkin on wannabeja?
rane28: kersa
uskova: mikä on simo??
Pakana .: tuskin oli oikea, kova fani kuitenkin
Finlandia: Simo oli yksi häirikkö
Uskonveli.: wannabe :D
Finlandia: Yhteen aikaan häiriköi täällä
Tuomas 1/12: ai tämä MOI-simo?
Finlandia: se oli Simo-fani
rane28: no eipäs tuomita
Pakana .: Ilmeisesti
Da Tishbyte: wannabe-simo
uskova: on ilmeisesti joku ilmiö
Uskonveli.: Tuomas 1/12: haluutko tulla huomatuksi
Pakana . => Uskonveli.: Raamtussa on melkein puolet turhaa
Uskonveli.: =)
rane28: ensviikolla viinaa ja lääkkeitä,jes
Finlandia: Noh, teini-ikään kuuluu Simo-ilmiö
Finlandia: Se on ihan normaalia
Da Tishbyte: jes
Tuomas 1/12:
Uskonveli.: Simo-ilmiö, tulee mieleen eppujen biisi Suomi-ilmiö :D
Jesse0000 liittyy keskusteluun
Tuomas 1/12: kyllä jokaisen kukan on sanottava moi... tai MOI MOI
Tuomas 1/12:
Victoria777 liittyy keskusteluun. Hän on chattäillyt 59016 minuutin ajan..
uskova => Tuomas 1/12:
Finlandia: Moi
Victoria777: M.o.l.s.k.i.s.t.a.
rane28: oho nyt mokasin,vic
Uskonveli. => Victoria777: Rauhaa =)
Victoria777 => Uskonveli.: samoin
uskova => Victoria777:
mämmikoura: Ladakuskien tervehdys; moi,moi monesko moottori?
Victoria777 => uskova:
Jesse0000: Jeesus elää!!!
Tuomas 1/12 => Victoria777: läps
rane28: et huomannu
Uskonveli.: ladat :D
Victoria777 => Tuomas 1/12: läps
Da Tishbyte: poltteliks jeesus ganjaa?
Pakana . => Uskonveli.: Miksi esimerkiksi luomiskertomus on raamatussa?
rane28: jes
Da Tishbyte: ku sehä joi viiniiki
Uskonveli.: ei jaska nyt väitellä
mämmikoura => Victoria777:
Victoria777 => mämmikoura:
Finlandia: Lada
Jesse0000: JEESUS ELÄÄ
rane28 => Victoria777: eiks näe mitä on kirjotettu kun tulee keskusteluun?
Tuomas 1/12 => Pakana .: Luomistarina on totuutta
Victoria777 => Finlandia: anteeksi ja siunausta
Finlandia => Victoria777: siunausta samoin
Victoria777 => rane28: näin osan
Pakana . => Uskonveli.: Mielestäni sillä ei ole mitään arvoa totuuden kannalta
uskova => Jesse0000: aamen
Väinämö poistui keskustelusta
Pakana . => Uskonveli.: Eikä muutoinkaan, ei se opeta mitään eikä neuvo mitään
repe. poistuu paikalta: liian pitkään keskustelematta.
Pakana . => Uskonveli.: se on vaan vanhan kansan uskomus
repe. => Victoria777:
Jesse0000: HALLE LUJAA
Victoria777 => repe.:
Finlandia: voihan simo
Da Tishbyte: kylhän historia opettaa
Uskonveli.: Jeesus totisesti elää
NaakkaNaakka poistui keskustelusta
NaakkaNaakka liittyy keskusteluun. Hän on chattäillyt 1024 minuutin ajan..
Victoria777: heti kun tuulettaa, niin haisee tupacci
Usvalintu: Halleluja!
Pakana . => Uskonveli.: mielestäni raamatun voisi supistaa pääasiallisesti jeesuksen filosofiaan ja opetuksiin joissa oli oikeastikkin järkeä
NaakkaNaakka: Ittaa lootaan!
Uskonveli.: iltaa
Tuomas 1/12:
Finlandia: ilitoo
Finlandia: Onks´ muuten Simoo näkynyt?
Finlandia: Victoria777: Wicca
Victoria777: NaakkaNaakka: Nocca!
Finlandia: En ole Simo en, olen häiriköinnyt ennen Simoa
Uskonveli.:
Finlandia: Simo meni pitemmälle kuin minä
NaakkaNaakka => Victoria777: Säkö taas vetelet röökiä siellä?
Jesse0000 poistui keskustelusta
Pakana . => Da Tishbyte: niinpä
Victoria777 => NaakkaNaakka: no en.
Victoria777 => NaakkaNaakka: sammuta toi piippu
Tuomas 1/12:
Uskonveli.: lasketko sä itsesi oikeaksi häiriköksi, niin kuin simonkin?
Pakana . => Da Tishbyte: varmaan on saatettu tehdäkkin jo
Da Tishbyte: vaikee uskoo etteikö raamattuun ois eksyny vähän turhaaki
Finlandia: Olen ollut joskus pikku-häirikkö
NaakkaNaakka => Victoria777: En mä ees nyt polta
Uskonveli.: ai wannabe? ;D
Victoria777 => NaakkaNaakka: Jaa.
Finlandia: Tai en ihan pikku-häirikkö, sain useita banneja
Finlandia: Tavallaan Simon edeltäjä
Uskonveli.: jäitkö kengännauhatasolle vai saikko oman fani-klubin? xD
Finlandia: En saanut omaa Fan Clubia
Uskonveli.:
mämmikoura: varma< kevään merkki, ;Simo ilmestyy kehiin
Victoria777: hh..
Finlandia: Miksi Simoa arvostetaan enemmän kuin minua
Tuomas 1/12: 1 joh 5:6. Hän on se, joka on tullut veden ja veren kautta, Jeesus Kristus, ei ainoastaan vedessä, vaan vedessä ja veressä; ja Henki on se, joka todistaa, sillä Henki on totuus.
MaryMagdalene liittyy keskusteluun. Hän on chattäillyt 27557 minuutin ajan..
NaakkaNaakka: Kuka on Simo?
Uskonveli.: unohdetaan jo se juttu
Finlandia: Jesh, päihitin Simon
Victoria777: mrh
Da Tishbyte: finlandia ehkä sä et oo floodinu tarpeeks
Finlandia: kaikki ei tiedä koko heppua
Victoria777: Jeesus No 1.
azrial poistuu paikalta: liian pitkään keskustelematta.
Finlandia: Floodasin keväällä -03 aika paljon
Usvalintu:
Tuomas 1/12: Mikä onkaan Jeesuksen Numero
Finlandia: silloin ei ollut sanasensuuria
Victoria777: 888 on se
Pakana . => Tuomas 1/12: mikset koskaan kirjoittele jeesuksen viisauksia jumaltodistuksien sijaan?
Uskonveli.: numero taivaaseen? risti kädet
uskova: Jeesus = this is my life
Tahko poistui keskustelusta
Finlandia: Uuno Turhapuro - This Is My Life
Tuomas 1/12 => Pakana .: Nuohan ovat niitä
Uskonveli.: sydämiä
repe. poistuu paikalta: liian pitkään keskustelematta.
Pakana . => Tuomas 1/12: tuo on selvitys jumalasta
uskova => Finlandia: katotaan just
Pakana . => Tuomas 1/12: ei sillä tavalla vaan jeesuksen elämänviisauksia
uskova => Finlandia:
Tuomas 1/12 => Pakana .: Joka oli Jeesuksessa..
Tuomas 1/12 => Pakana .: okei... mielelläni
Finlandia: Titanic
Tuomas 1/12 => Pakana .: mitä haluat?
Tahko liittyy keskusteluun
Taumii liittyy keskusteluun. Hän on chattäillyt 62 minuutin ajan..
Pakana . => Tuomas 1/12: en osaa nimetä mutta mielestäni juuri niihin kannattaisi eniten tutustua raamatussa
Uskonveli.: jazzia
Tuomas 1/12 => Pakana .: luukas 10:24. Minä sanon teille: monet profeetat ja kuninkaat ovat halunneet nähdä sen, mitä te näette, eivätkä ole nähneet, ja kuulla sen, mitä te kuulette, eivätkä ole kuulleet."
mämmikoura: Koska täällä on nyt niin suuri pilvi todistajia ympärillämme, niin kiinnittäkäämme katseemme Jeesukseen ristukseen. Uskon alkajaan ja täyttäjään
Taumii: Kalle Aholaa
Finlandia: Kukahan oli ensimmäinen häirikkö?
Tuomas 1/12 => Pakana .: Koko Raamattu on Jeesuksen sanomaa
Taumii:
Pakana . => Tuomas 1/12: niissä on oikeasti järkeäonhan siinä turhaakin kuten luomistarina
Pakana . => Tuomas 1/12: ja muuta jumaltodistuksia
MaryMagdalene poistui keskustelusta
Finlandia: Häiriköille oma huone ja huoneen nimeksi Simo Café
Tuomas 1/12 => Pakana .: Luomistarina on todiste Totuudesta
Taumii: Koko nyt joku tarttuu ajatukseen, että Paavi on rienaamista..
mirva1 liittyy keskusteluun
Tuomas 1/12 => Pakana .: samoin kuin muutkin profetiat
Uskonveli. kuiskaa: Te olette kuulleet sanotuksi: 'Silmä silmästä ja hammas hampaasta'. Mutta minä sanon teille: älkää tehkö pahalle vastarintaa. Jos joku lyö sinua oikealle poskelle, käännä hänelle vasenkin.
Hazelhen liittyy keskusteluun
Pakana . => Tuomas 1/12: mielestäni suurin totuus seisoo jeesuksen viisauksien takana
Taumii: kuiskaus kuuluu huutoa paremmin.
Finlandia: Jos joku lyö, lyö takaisin!
Pakana . => Tuomas 1/12: muut ovat vähän kuin kuorrutusta sille
mirva1 poistui keskustelusta
Johan-On-Kumma liittyy keskusteluun. Hän on chattäillyt 4474 minuutin ajan..
Taumii:
Pakana . => Tuomas 1/12: koska niissä on oikeasti järkeä aika ajoin
Da Tishbyte: uskonveli eihä se mitää tommost oo sanonu
Hazelhen: iltaa
NaakkaNaakka poistuu paikalta: liian pitkään keskustelematta.
Uskonveli.: Rakkaus on vihaa väkevämpi
Da Tishbyte: tos oo mitää järkee
Finlandia: Kysely: Onko Kirkkokahvilan keskustelu mennyt huonompaan vai parempaan suuntaan?
Tuomas 1/12 => Pakana .: Ei pidä paikkaansa... Jeesuskin viittasi Raamattuun (kuten kirjoitettu on...) muutenhan Hänenkin sanansa olisi evättävissä
mask liittyy keskusteluun
Uskonveli.: niin teki
Taumii: Ainakin täällä on joku jako kenen kanssa puhutaan?
uskova: Jeesus on Herra
Usvalintu poistuu paikalta: liian pitkään keskustelematta.
Tuomas 1/12 => Pakana .: Jopa Saatana uskoo Sanan voimaan
rane28 poistui keskustelusta
Uskonveli.: Jeesus on se josta profeetat ennustivat
mämmikoura poistui keskustelusta
Victoria777: amen, halleluja.. Jeesus Kristus voitti kuoleman!
Mont Everest: Jeesuksen siunausta ja ihanaa ylösnousemuksen juhlaa kaikille siskoille ja veljille Herrassa! Nyt täytyy tämän mummelin mennä saunaan. Siunausta kaikille!
Taumii: Ja miten ihmeessä keskustella, kun pukkaa sydäntä ja kristusta..
Uskonveli. => Mont Everest:
uskova => Mont Everest:
Finlandia: niinpä
Victoria777: Kysymyksiä?
Johan-On-Kumma => Taumii: joskus on joskus ei
Taumii: Tulee olo, että pitäisi syödä sieniä itsekin
Pakana . => Tuomas 1/12: hmmm, ehkäpä tämä on vain ateistin näkökulma
Taumii: No johan on kumma!
Da Tishbyte: öitä mont
Uskonveli.: Jeesuksen ohjeet ovat käyttökelpoisia niin ateisteille kuin uskovillekin
Victoria777: sieniä
Finlandia: Kärpässieniä
Mont Everest poistui keskustelusta
Johan-On-Kumma: jep näin on
Usvalintu => Victoria777: ai mittee kysymyksijä?
Taumii: No välillä tuntuu siltä
Tuomas 1/12: Raamattu on jokaiselle
Taumii:
Tahko poistuu paikalta: liian pitkään keskustelematta.
Pakana . => Tuomas 1/12: jeesus on saattanut olla joku fiksu mies joka ollaan korotettu jumalaksi kansan toimesta
Uskonveli. kuiskaa: "Teille on opetettu: 'Rakasta lähimmäistäsi ja vihaa vihamiestäsi.' Mutta minä sanon teille: rakastakaa vihamiehiänne ja rukoilkaa vainoojienne puolesta
Taumii:
infernum liittyy keskusteluun. Hän on chattäillyt 931 minuutin ajan..
Pakana . => Tuomas 1/12: itse on saattanut vastustaakkin sitä
Uskonveli.: Millainen maailma olisi jos kaikki noudattaisivat tuota opetusta?
uskova: Herramme Jeesus sinä yönä jona Hänet kavallettiin
Finlandia: Nämä hymiöt pitäisi ottaa pois
wil-ma poistui keskustelusta
Victoria777: Terapia: Täällä taas
Taumii: Ei sentään.
Da Tishbyte: eihä missää raamatus lue et jeesus on jumala
uskova: mursi leivän ja antoi opetuslapsille
Taumii: Ei hymyöitä pois.
Usvalintu => Victoria777: taasko ne on täällä?
Finlandia: ennen ei niitä ollut
Victoria777: hymiörivistöstä puuttuu mm. risti, pääkallo, motskari, Snoopy ja muutama muu.
Victoria777 => Usvalintu: on ne.
uskova: tämä leipä on minun ruumiini, joka teidän edestänne annetaan
Taumii: Niin no valikoima kaipaa hienosäätöä.
infernum: wasp - wild child
Taumii: Olis hienoa, kun saisi aina ristinkin silmilleen..
Victoria777:
pikkulotta liittyy keskusteluun. Hän on chattäillyt 31179 minuutin ajan..
uskova: tämä viini, on minun vereni, joka teidän edestänne vuodatetaan
Uskonveli.: lottis missas simpan
Taumii: Ja veriefektejä.
Finlandia: Simppa kerkesi jo menemään ajat sitten
Victoria777: ei efektejä
infernum: hitto kun noi naapurit bilettää äänekkäästi ja mä mädännyn himas
adsl-m liittyy keskusteluun
infernum: hieman kyrsii
hundmåt: no lähe baariin kupposelle
Tuomas 1/12 => Pakana .: Jeesuksen työ ei ollut helppo... Vain Jumala pystyi siihen mitä Jeesuksessa teki
Uskonveli.: tässä maailmassa on paljon viettelyksiä
infernum: no joo, mielelläni menisinki mut ei ole ikää
Victoria777: kupponen kello viiden teetä
Taumii: Viettelyksiä..
Taumii:
Victoria777: **ilo Herrassa on voimani**
Finlandia: Simppa saisi tulla takaisin, niin lottis voisi antaa bannin sille
Hazelhen => Taumii: ei oo ristiä silmille, mutta täs ois silmät ristissä
infernum: kohta sitten pääsee flippaamaan laillisesti
uskova: Halleluja
Taumii:
Pakana . => Tuomas 1/12: Itse voisin uskoa että jeesus on viisauksillaan tuonut lohtua ja toivoa ahdistetulle kansalle ja näin saanut suosiota ja jotkut korottanut jumalaksi
Tahko poistui keskustelusta
infernum: jee
Victoria777: Aivastuksen nopeus on jopa 70km/h . *nippelitieto*
Pakana . => Tuomas 1/12: Jeesus saattaisi olla jonkinlainen filosofi
Victoria777: *sniis*
Pakana . => Tuomas 1/12: tai oli
azrial poistuu paikalta: liian pitkään keskustelematta.
mask poistuu paikalta: liian pitkään keskustelematta.
Tuomas 1/12 => Pakana .: Niin hän lupasi... puhui siinäkin totta... Joka itsensä korottaa se alennetaan
Pakana . => Tuomas 1/12: jolla on ollut vain hieman näkemystä
infernum: jaa, jaa
Hazelhen => infernum: huonoo huumorii vai
Tuomas 1/12 => Pakana .: (aasilla ratsasti, pesi opetuslasten jalat)
Taumii:
Uskonveli.: Jeesus on elävän Jumalan poika
infernum => Hazelhen: eikös se ole ainoota mitä on?
Tuomas 1/12 => Pakana .: Ihmisten oli korotettava, koska Hän oli rakkaus, Jumala
uskova => pikkulotta: sefu paikalla
Ex-pertti liittyy keskusteluun. Hän on chattäillyt 5 minuutin ajan..
Tuomas 1/12 => Pakana .: Hän alansi itsensä, vaikka tiesi olevansa Jumala
Finlandia: Ei uskalla Simppa tulla takaisin
pikkulotta poistuu paikalta: kattoo äiti teresaa......
Victoria777: Terapia: Helvetti takana
Uskonveli. => Ex-pertti: hauska nikki sulla
adsl-m poistui keskustelusta
Tuomas 1/12 => Pakana .: Muuten ei olisi ollut esimerkkikään meille
infernum: onpas broidilla surkeita biiseijä koneel
Victoria777: Menen nyt tullakseni taas takaisin.
Victoria777 poistui keskustelusta
Kirjoita /apua jos tarvitset lisää ohjeita chattailyyn.
Älä anna koskaan henkilökohtaisia tietojasi (nimeä, puhelinnumeroa) chatissä.
hundmåt => Mont Everest: sanoin että synti on näkökantakysymys... siis toisen synti voi olla toiselle hyve koska asiat määritellään eri tavalla eri kulttuureissa
Mont Everest: Jeesus ristiinnaulittiin juuri sen takia, että Hän sanoi itseään Jumalaksi, ja se oli papeille (!) liikaa.
Pakana . => Mont Everest: Tai Jeesusta pidettiin jumalana
Pakana . => Mont Everest: Tuntuu vähän että jos tosiaan on senkin verran fiksu ja totuutta kunnioittava ihminen kuin jeesus olisi saattanut olla tajutessaan sen minkä oli tajunnut ettei korottaisi itseään jumalaksi
Mont Everest => hundmåt: Synti-kysymystä täytykin katsoa Jumalan Sanan näkövinkkelistä, punnita asiat Sanalla.
-SIMO-: hahahaa
Da Tishbyte: eiks jeesus sanonu olevansa jumalan poika
hundmåt => Mont Everest: siis mie punnitan asiat neutraalista näkökulmasta
-SIMO-: tuliko paskat housuun häh?
hundmåt => Mont Everest: ja en ole kristitty nii miksi mie raamatulla punnittaisin mitään
rane28 liittyy keskusteluun. Hän on chattäillyt 287 minuutin ajan..
Finlandia: Terve
UsKoVa93 poistui keskustelusta
-SIMO-: pellet
Mont Everest => Pakana .: Jeesus on Jumala. Minun Herrani ja minun Jumalani.
Pakana . => Mont Everest: jeesus on saattanut olla joku hieman fiksumpi ihminen joka ollaan väritetty jumalaksi
rane28: iltaa
Finlandia: taas sitten tällainen yhdistetty uskonto ja häirikköilta?
Finlandia: iltaa
Pakana . => Mont Everest: ja jos on ollut niin fiksu mitä raamattu antaa ymmärtää niin tuskin on jumalaksi itseään korottanut
rane28: toni rantalaa näkyny?
Tahko: " kaikki joka ei ole uskosta on synti "
rane28: intoilijat
-SIMO- => Tahko: oosää idiootti vaa hiljaa!
hundmåt => Pakana .: miksei olisi
hundmåt => Pakana .: sehä o yleistä näillä kulttien johtajahahmoilla
hundmåt => Pakana .: kute nykyäänkin hyvin näkee
Pakana . => hundmåt: en usko että niin fiksu olisi itseään jumalaksi korottanut
UsKoVa-93 poistui keskustelusta
Mont Everest: PÄÄSIÄISEN SANOMA KUULUU: JEESUS ON NOUSSUT KUOLLEISTA! Hän elää ja tulee pian noutamaan omansa taivaan kotiin kuninkaallisiin häihin. Silloin täällä maan päällä alkaa suuri ahdistuksen aika!
Finlandia: taas näitä Simoja....
rane28: miten käy raamatun mukaan jos tappaa itsensä?
Pakana . => hundmåt: luulen että hänet on jälkikäteen korotettu jumalaksi
hundmåt => Pakana .: no onha noista kulttijohtajista moni erittäin älykkäitä ihmisiä mutta korottavat itsensä jumalaksi koska seuraajat eivät kyseenalaista
Pakana . => hundmåt: varmaankin
Kärpässieni poistuu paikalta: liian pitkään keskustelematta.
Finlandia: helvetillä pelottelijat
rane28: jep
Kärpässieni: Johan on markkinat taas.
Pakana . => hundmåt: tuli vaan tuosta eilisestä gandhi ohjelmasta mieleen että on saattanut olla sellainen gandhin tapainen valaistuja
Mont Everest: Merkkejä tästä kaikesta on havaittavissa!
Kärpässieni: PItäisköhän minun lähteä kiltisti nukkumaan perhana vieköön.
Finlandia: kuten mitä?
rane28: kukaan ei valitse tänne tulemista
Pakana . => hundmåt: ja tilannekkin on ollut sama, miehitetty israel ja miehitetty intia
Kärpässieni: Päätäni särkee perkeleet.
hundmåt => Pakana .: no jessestä paha sanoa ku siitä ole infoa juri
Pakana . => hundmåt: ja sama periaate että pitää hyvällä, ilman kostoa ym selvittää asiat
rane28: v kantaa
repe. => Pakana .: pa-paha kana -kana
Kärpässieni: Voihan sietana sumpare nyt .
Da Tishbyte: joo ei kande olla tääl ku jeesus tulee hakee sen posset
Pakana . => hundmåt: no ei ole mutta voisi helpolla kuvitella
Finlandia: paskapuhetta
Mont Everest => rane28: Murhamies ei ole Isää näkevä, sanoo Raamattu. Jää vain sitten arvailuksi, miten on käynyt, jos viime henkäisyllään onkin turvautunut Jeesukseen ja pelastunut, niinkuin toinen ryöväri ristillä.
Finlandia: tuota on jauhettu jo melkein 2000 vuotta
Hikkis liittyy keskusteluun
Hikkis:
Jumprahuiti poistui keskustelusta
rane28: kiitti
-SIMO-: dhhudfuifhffe
-SIMO-: duueeyue
-SIMO-: erfgrgreugfrt
-SIMO-: 5th45ty58
-SIMO-: sori
-SIMO-:
hundmåt => Mont Everest: puuh mie ole ikuna uskonu ja ns. kuolinvuoteella tullu edes mieleenkään rukoilla
hundmåt => Mont Everest: ja silti miusta mikää roisto tullut :D
Tuomas 1/12 liittyy keskusteluun
rane28: mut jos uskoo mutta ei kertakaikkiaan jaksa enää?
azrial poistuu paikalta: liian pitkään keskustelematta.
Hikkis: naiset on tänään pois täältä
Juoppo_ liittyy keskusteluun
Uskonveli. liittyy keskusteluun
Mont Everest => rane28: Ne asiat ovat onneksi Jumalan kädessä. Muutoin moni nääntyisi suruunsa, ellei sitä toivoa olisi!
Tuomas 1/12: iltaa
-SIMO-: MOI MOI MOI MOIMOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI M MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Uskonveli.: Rauhan tervehdys
Juoppo_: Hetkinen...
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Miksei ole naisia?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Hikkis:
Da Tishbyte: hund jos sä et usko hyvään etkä pahaan ni ethän sä voi tunnistaa niitä ja mistä sä tiiät ootko tehny kuinka hyvii juttuja tai kuinka pahoi
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tahko poistuu paikalta: liian pitkään keskustelematta.
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Hikkis:
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: lopeta!!!!!!!!!!!!!!!!!!!!!!!
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Hikkis:
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Uskonveli.: paina nimen vieressä olevasta ruksista
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: kuulitko
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova liittyy keskusteluun. Hän on chattäillyt 5917 minuutin ajan..
rane28: v**** moi
Finlandia: taas tätä....
Uskonveli. => uskova: Jumalan rauhaa
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Pakana . => hundmåt: on helppo kuvitella että sellainen olisi herättänyt huomiota ja jotkut ovat sitten innostuneet niin että tuo on varmaan messias
Finlandia poistuu paikalta: En jaksa.....
Olet tauolla, sano jotain jatkaaksesi.
Tuomas 1/12 => uskova: olen kuullut tästä, mutta nyt vasta näen
rane28: ookko sairaampi ku mä
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Mont Everest => hundmåt: Et koiranmuona lukenut, kun kirjoitin erään kuolinvuoteella pelastuneen tapauksesta?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Mitäs sanoisitte, jos ottasin tässä muutamat oluet ja lähtisin baariin??
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Pakana . => hundmåt: varmaan ollut itse vaatimaton ja hyvinkin askeettinen
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova => Uskonveli.: Rauhaa
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Autolla
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12 => Finlandia: kutsuitko simon tänne?
Hikkis poistui keskustelusta
Finlandia => Tuomas 1/12: en todellakaan
Uskonveli.: nimen vieressä on raksi, siitä painamalla voi hiljentää keskustelijan
uskova => Tuomas 1/12: siis mitä tapahtuu
Finlandia => Tuomas 1/12: lieneekö oikea Simo
Pakana . => hundmåt: jotkut uskonut väkisin että hän on jumala vaikka on itse kieltänyt sen ja siksi ristiinnaulittukkin
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12 => -SIMO-: rauhaa rakas
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Juoppo_: Ette sano mtn?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: ookko sä noin tyhymä?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: jee jätkä leikkii
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12: ruks
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Mont Everest => hundmåt: Hän eli kapakkamaailmassa elämänsä, joi ja rellesti, huorasi ja vähät välitti Jumalasta. Kun joutui kuolinvuoteeseen, huusi tuskissaan apua, soitti puolisolleni, että tuu heti tänne! Ja kun sai kuulla
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Uskonveli.: uskovien yhteyden häirinnästä en tykkää
Finlandia => -SIMO-: *ruks*
-SIMO-: SENKIN PELLET
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
repe. poistuu paikalta: liian pitkään keskustelematta.
rane28: mee tarhaan
Kärpässieni poistuu paikalta: liian pitkään keskustelematta.
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Mont Everest => hundmåt: Jeesuksesta, otti Hänet heti vastaan: Ette voi kuvitella sitä iloa ja rauhaa. Sanoi olevansa maailman onnellisin mies, eikä sitten kyllä hävennyt Jeesusta!!!
Uskonveli.: ug ookko täällä jollain sananikillä?
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova => -SIMO-: Jeesuksen nimessä lopeta
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Tuomas 1/12 => Finlandia: Mä vähän ymmärrän mitä puhuit..
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
rane28: en mäkään mikään uskon intoilija ,mut heittäkää toi pihalle
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
hundmåt => Mont Everest: nii siis kuka sanoi
Finlandia: ruksein jo sen
repe.:
Uskonveli.: ei täällä oo seriffiä paikalla
Finlandia => Tuomas 1/12: ruksein jo sen
Juoppo_: Ettekö oikeesti sano mtn tohon?
-SIMO-: BÖÖRTIIUTG
Pakana .: Kaikki privassa floodaamaan simolle takaisin
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
uskova: Jeesus on paikalla
-SIMO-: MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI MOI
Kärpässieni poistui keskustelusta
Finlandia: ihme tapa toivottaa päivää tuollakin
uskova => -SIMO-: Jeesus katso tämän ihmisen puoleen
Uskonveli.: Jeesus elää
Juoppo_: Ei sitte, heippa -->
Tuomas 1/12 => Pakana .: luuletko että siitä on iloa
-SIMO-: Toivotin päivää!
Finlandia: erikoinen tapa toivottaa
uskova => -SIMO-: päivää sullekin
Uskonveli.: \0/ \0/
Juoppo_ poistui keskustelusta
Pakana . => Tuomas 1/12: No ei välttämättä iloa
rane28: no älä sitten ota itsees
repe.: jumala sanoo sulle simo henkilökohtaisesti jos et lopeta pelleilyä annan sulle halvauksen
Da Tishbyte poistuu paikalta: liian pitkään keskustelematta.
Tuomas 1/12 => -SIMO-: Jeesus kuulee pienimmänkin avunhuudon
uskova => -SIMO-: Jeesukselle olet rakas
-SIMO- poistui keskustelusta
Finlandia: olikohan tuo edes oikea Simo
Uskonveli.: meinaatko että häiriköitäkin on wannabeja?
rane28: kersa
uskova: mikä on simo??
Pakana .: tuskin oli oikea, kova fani kuitenkin
Finlandia: Simo oli yksi häirikkö
Uskonveli.: wannabe :D
Finlandia: Yhteen aikaan häiriköi täällä
Tuomas 1/12: ai tämä MOI-simo?
Finlandia: se oli Simo-fani
rane28: no eipäs tuomita
Pakana .: Ilmeisesti
Da Tishbyte: wannabe-simo
uskova: on ilmeisesti joku ilmiö
Uskonveli.: Tuomas 1/12: haluutko tulla huomatuksi
Pakana . => Uskonveli.: Raamtussa on melkein puolet turhaa
Uskonveli.: =)
rane28: ensviikolla viinaa ja lääkkeitä,jes
Finlandia: Noh, teini-ikään kuuluu Simo-ilmiö
Finlandia: Se on ihan normaalia
Da Tishbyte: jes
Tuomas 1/12:
Uskonveli.: Simo-ilmiö, tulee mieleen eppujen biisi Suomi-ilmiö :D
Jesse0000 liittyy keskusteluun
Tuomas 1/12: kyllä jokaisen kukan on sanottava moi... tai MOI MOI
Tuomas 1/12:
Victoria777 liittyy keskusteluun. Hän on chattäillyt 59016 minuutin ajan..
uskova => Tuomas 1/12:
Finlandia: Moi
Victoria777: M.o.l.s.k.i.s.t.a.
rane28: oho nyt mokasin,vic
Uskonveli. => Victoria777: Rauhaa =)
Victoria777 => Uskonveli.: samoin
uskova => Victoria777:
mämmikoura: Ladakuskien tervehdys; moi,moi monesko moottori?
Victoria777 => uskova:
Jesse0000: Jeesus elää!!!
Tuomas 1/12 => Victoria777: läps
rane28: et huomannu
Uskonveli.: ladat :D
Victoria777 => Tuomas 1/12: läps
Da Tishbyte: poltteliks jeesus ganjaa?
Pakana . => Uskonveli.: Miksi esimerkiksi luomiskertomus on raamatussa?
rane28: jes
Da Tishbyte: ku sehä joi viiniiki
Uskonveli.: ei jaska nyt väitellä
mämmikoura => Victoria777:
Victoria777 => mämmikoura:
Finlandia: Lada
Jesse0000: JEESUS ELÄÄ
rane28 => Victoria777: eiks näe mitä on kirjotettu kun tulee keskusteluun?
Tuomas 1/12 => Pakana .: Luomistarina on totuutta
Victoria777 => Finlandia: anteeksi ja siunausta
Finlandia => Victoria777: siunausta samoin
Victoria777 => rane28: näin osan
Pakana . => Uskonveli.: Mielestäni sillä ei ole mitään arvoa totuuden kannalta
uskova => Jesse0000: aamen
Väinämö poistui keskustelusta
Pakana . => Uskonveli.: Eikä muutoinkaan, ei se opeta mitään eikä neuvo mitään
repe. poistuu paikalta: liian pitkään keskustelematta.
Pakana . => Uskonveli.: se on vaan vanhan kansan uskomus
repe. => Victoria777:
Jesse0000: HALLE LUJAA
Victoria777 => repe.:
Finlandia: voihan simo
Da Tishbyte: kylhän historia opettaa
Uskonveli.: Jeesus totisesti elää
NaakkaNaakka poistui keskustelusta
NaakkaNaakka liittyy keskusteluun. Hän on chattäillyt 1024 minuutin ajan..
Victoria777: heti kun tuulettaa, niin haisee tupacci
Usvalintu: Halleluja!
Pakana . => Uskonveli.: mielestäni raamatun voisi supistaa pääasiallisesti jeesuksen filosofiaan ja opetuksiin joissa oli oikeastikkin järkeä
NaakkaNaakka: Ittaa lootaan!
Uskonveli.: iltaa
Tuomas 1/12:
Finlandia: ilitoo
Finlandia: Onks´ muuten Simoo näkynyt?
Finlandia: Victoria777: Wicca
Victoria777: NaakkaNaakka: Nocca!
Finlandia: En ole Simo en, olen häiriköinnyt ennen Simoa
Uskonveli.:
Finlandia: Simo meni pitemmälle kuin minä
NaakkaNaakka => Victoria777: Säkö taas vetelet röökiä siellä?
Jesse0000 poistui keskustelusta
Pakana . => Da Tishbyte: niinpä
Victoria777 => NaakkaNaakka: no en.
Victoria777 => NaakkaNaakka: sammuta toi piippu
Tuomas 1/12:
Uskonveli.: lasketko sä itsesi oikeaksi häiriköksi, niin kuin simonkin?
Pakana . => Da Tishbyte: varmaan on saatettu tehdäkkin jo
Da Tishbyte: vaikee uskoo etteikö raamattuun ois eksyny vähän turhaaki
Finlandia: Olen ollut joskus pikku-häirikkö
NaakkaNaakka => Victoria777: En mä ees nyt polta
Uskonveli.: ai wannabe? ;D
Victoria777 => NaakkaNaakka: Jaa.
Finlandia: Tai en ihan pikku-häirikkö, sain useita banneja
Finlandia: Tavallaan Simon edeltäjä
Uskonveli.: jäitkö kengännauhatasolle vai saikko oman fani-klubin? xD
Finlandia: En saanut omaa Fan Clubia
Uskonveli.:
mämmikoura: varma< kevään merkki, ;Simo ilmestyy kehiin
Victoria777: hh..
Finlandia: Miksi Simoa arvostetaan enemmän kuin minua
Tuomas 1/12: 1 joh 5:6. Hän on se, joka on tullut veden ja veren kautta, Jeesus Kristus, ei ainoastaan vedessä, vaan vedessä ja veressä; ja Henki on se, joka todistaa, sillä Henki on totuus.
MaryMagdalene liittyy keskusteluun. Hän on chattäillyt 27557 minuutin ajan..
NaakkaNaakka: Kuka on Simo?
Uskonveli.: unohdetaan jo se juttu
Finlandia: Jesh, päihitin Simon
Victoria777: mrh
Da Tishbyte: finlandia ehkä sä et oo floodinu tarpeeks
Finlandia: kaikki ei tiedä koko heppua
Victoria777: Jeesus No 1.
azrial poistuu paikalta: liian pitkään keskustelematta.
Finlandia: Floodasin keväällä -03 aika paljon
Usvalintu:
Tuomas 1/12: Mikä onkaan Jeesuksen Numero
Finlandia: silloin ei ollut sanasensuuria
Victoria777: 888 on se
Pakana . => Tuomas 1/12: mikset koskaan kirjoittele jeesuksen viisauksia jumaltodistuksien sijaan?
Uskonveli.: numero taivaaseen? risti kädet
uskova: Jeesus = this is my life
Tahko poistui keskustelusta
Finlandia: Uuno Turhapuro - This Is My Life
Tuomas 1/12 => Pakana .: Nuohan ovat niitä
Uskonveli.: sydämiä
repe. poistuu paikalta: liian pitkään keskustelematta.
Pakana . => Tuomas 1/12: tuo on selvitys jumalasta
uskova => Finlandia: katotaan just
Pakana . => Tuomas 1/12: ei sillä tavalla vaan jeesuksen elämänviisauksia
uskova => Finlandia:
Tuomas 1/12 => Pakana .: Joka oli Jeesuksessa..
Tuomas 1/12 => Pakana .: okei... mielelläni
Finlandia: Titanic
Tuomas 1/12 => Pakana .: mitä haluat?
Tahko liittyy keskusteluun
Taumii liittyy keskusteluun. Hän on chattäillyt 62 minuutin ajan..
Pakana . => Tuomas 1/12: en osaa nimetä mutta mielestäni juuri niihin kannattaisi eniten tutustua raamatussa
Uskonveli.: jazzia
Tuomas 1/12 => Pakana .: luukas 10:24. Minä sanon teille: monet profeetat ja kuninkaat ovat halunneet nähdä sen, mitä te näette, eivätkä ole nähneet, ja kuulla sen, mitä te kuulette, eivätkä ole kuulleet."
mämmikoura: Koska täällä on nyt niin suuri pilvi todistajia ympärillämme, niin kiinnittäkäämme katseemme Jeesukseen ristukseen. Uskon alkajaan ja täyttäjään
Taumii: Kalle Aholaa
Finlandia: Kukahan oli ensimmäinen häirikkö?
Tuomas 1/12 => Pakana .: Koko Raamattu on Jeesuksen sanomaa
Taumii:
Pakana . => Tuomas 1/12: niissä on oikeasti järkeäonhan siinä turhaakin kuten luomistarina
Pakana . => Tuomas 1/12: ja muuta jumaltodistuksia
MaryMagdalene poistui keskustelusta
Finlandia: Häiriköille oma huone ja huoneen nimeksi Simo Café
Tuomas 1/12 => Pakana .: Luomistarina on todiste Totuudesta
Taumii: Koko nyt joku tarttuu ajatukseen, että Paavi on rienaamista..
mirva1 liittyy keskusteluun
Tuomas 1/12 => Pakana .: samoin kuin muutkin profetiat
Uskonveli. kuiskaa: Te olette kuulleet sanotuksi: 'Silmä silmästä ja hammas hampaasta'. Mutta minä sanon teille: älkää tehkö pahalle vastarintaa. Jos joku lyö sinua oikealle poskelle, käännä hänelle vasenkin.
Hazelhen liittyy keskusteluun
Pakana . => Tuomas 1/12: mielestäni suurin totuus seisoo jeesuksen viisauksien takana
Taumii: kuiskaus kuuluu huutoa paremmin.
Finlandia: Jos joku lyö, lyö takaisin!
Pakana . => Tuomas 1/12: muut ovat vähän kuin kuorrutusta sille
mirva1 poistui keskustelusta
Johan-On-Kumma liittyy keskusteluun. Hän on chattäillyt 4474 minuutin ajan..
Taumii:
Pakana . => Tuomas 1/12: koska niissä on oikeasti järkeä aika ajoin
Da Tishbyte: uskonveli eihä se mitää tommost oo sanonu
Hazelhen: iltaa
NaakkaNaakka poistuu paikalta: liian pitkään keskustelematta.
Uskonveli.: Rakkaus on vihaa väkevämpi
Da Tishbyte: tos oo mitää järkee
Finlandia: Kysely: Onko Kirkkokahvilan keskustelu mennyt huonompaan vai parempaan suuntaan?
Tuomas 1/12 => Pakana .: Ei pidä paikkaansa... Jeesuskin viittasi Raamattuun (kuten kirjoitettu on...) muutenhan Hänenkin sanansa olisi evättävissä
mask liittyy keskusteluun
Uskonveli.: niin teki
Taumii: Ainakin täällä on joku jako kenen kanssa puhutaan?
uskova: Jeesus on Herra
Usvalintu poistuu paikalta: liian pitkään keskustelematta.
Tuomas 1/12 => Pakana .: Jopa Saatana uskoo Sanan voimaan
rane28 poistui keskustelusta
Uskonveli.: Jeesus on se josta profeetat ennustivat
mämmikoura poistui keskustelusta
Victoria777: amen, halleluja.. Jeesus Kristus voitti kuoleman!
Mont Everest: Jeesuksen siunausta ja ihanaa ylösnousemuksen juhlaa kaikille siskoille ja veljille Herrassa! Nyt täytyy tämän mummelin mennä saunaan. Siunausta kaikille!
Taumii: Ja miten ihmeessä keskustella, kun pukkaa sydäntä ja kristusta..
Uskonveli. => Mont Everest:
uskova => Mont Everest:
Finlandia: niinpä
Victoria777: Kysymyksiä?
Johan-On-Kumma => Taumii: joskus on joskus ei
Taumii: Tulee olo, että pitäisi syödä sieniä itsekin
Pakana . => Tuomas 1/12: hmmm, ehkäpä tämä on vain ateistin näkökulma
Taumii: No johan on kumma!
Da Tishbyte: öitä mont
Uskonveli.: Jeesuksen ohjeet ovat käyttökelpoisia niin ateisteille kuin uskovillekin
Victoria777: sieniä
Finlandia: Kärpässieniä
Mont Everest poistui keskustelusta
Johan-On-Kumma: jep näin on
Usvalintu => Victoria777: ai mittee kysymyksijä?
Taumii: No välillä tuntuu siltä
Tuomas 1/12: Raamattu on jokaiselle
Taumii:
Tahko poistuu paikalta: liian pitkään keskustelematta.
Pakana . => Tuomas 1/12: jeesus on saattanut olla joku fiksu mies joka ollaan korotettu jumalaksi kansan toimesta
Uskonveli. kuiskaa: "Teille on opetettu: 'Rakasta lähimmäistäsi ja vihaa vihamiestäsi.' Mutta minä sanon teille: rakastakaa vihamiehiänne ja rukoilkaa vainoojienne puolesta
Taumii:
infernum liittyy keskusteluun. Hän on chattäillyt 931 minuutin ajan..
Pakana . => Tuomas 1/12: itse on saattanut vastustaakkin sitä
Uskonveli.: Millainen maailma olisi jos kaikki noudattaisivat tuota opetusta?
uskova: Herramme Jeesus sinä yönä jona Hänet kavallettiin
Finlandia: Nämä hymiöt pitäisi ottaa pois
wil-ma poistui keskustelusta
Victoria777: Terapia: Täällä taas
Taumii: Ei sentään.
Da Tishbyte: eihä missää raamatus lue et jeesus on jumala
uskova: mursi leivän ja antoi opetuslapsille
Taumii: Ei hymyöitä pois.
Usvalintu => Victoria777: taasko ne on täällä?
Finlandia: ennen ei niitä ollut
Victoria777: hymiörivistöstä puuttuu mm. risti, pääkallo, motskari, Snoopy ja muutama muu.
Victoria777 => Usvalintu: on ne.
uskova: tämä leipä on minun ruumiini, joka teidän edestänne annetaan
Taumii: Niin no valikoima kaipaa hienosäätöä.
infernum: wasp - wild child
Taumii: Olis hienoa, kun saisi aina ristinkin silmilleen..
Victoria777:
pikkulotta liittyy keskusteluun. Hän on chattäillyt 31179 minuutin ajan..
uskova: tämä viini, on minun vereni, joka teidän edestänne vuodatetaan
Uskonveli.: lottis missas simpan
Taumii: Ja veriefektejä.
Finlandia: Simppa kerkesi jo menemään ajat sitten
Victoria777: ei efektejä
infernum: hitto kun noi naapurit bilettää äänekkäästi ja mä mädännyn himas
adsl-m liittyy keskusteluun
infernum: hieman kyrsii
hundmåt: no lähe baariin kupposelle
Tuomas 1/12 => Pakana .: Jeesuksen työ ei ollut helppo... Vain Jumala pystyi siihen mitä Jeesuksessa teki
Uskonveli.: tässä maailmassa on paljon viettelyksiä
infernum: no joo, mielelläni menisinki mut ei ole ikää
Victoria777: kupponen kello viiden teetä
Taumii: Viettelyksiä..
Taumii:
Victoria777: **ilo Herrassa on voimani**
Finlandia: Simppa saisi tulla takaisin, niin lottis voisi antaa bannin sille
Hazelhen => Taumii: ei oo ristiä silmille, mutta täs ois silmät ristissä
infernum: kohta sitten pääsee flippaamaan laillisesti
uskova: Halleluja
Taumii:
Pakana . => Tuomas 1/12: Itse voisin uskoa että jeesus on viisauksillaan tuonut lohtua ja toivoa ahdistetulle kansalle ja näin saanut suosiota ja jotkut korottanut jumalaksi
Tahko poistui keskustelusta
infernum: jee
Victoria777: Aivastuksen nopeus on jopa 70km/h . *nippelitieto*
Pakana . => Tuomas 1/12: Jeesus saattaisi olla jonkinlainen filosofi
Victoria777: *sniis*
Pakana . => Tuomas 1/12: tai oli
azrial poistuu paikalta: liian pitkään keskustelematta.
mask poistuu paikalta: liian pitkään keskustelematta.
Tuomas 1/12 => Pakana .: Niin hän lupasi... puhui siinäkin totta... Joka itsensä korottaa se alennetaan
Pakana . => Tuomas 1/12: jolla on ollut vain hieman näkemystä
infernum: jaa, jaa
Hazelhen => infernum: huonoo huumorii vai
Tuomas 1/12 => Pakana .: (aasilla ratsasti, pesi opetuslasten jalat)
Taumii:
Uskonveli.: Jeesus on elävän Jumalan poika
infernum => Hazelhen: eikös se ole ainoota mitä on?
Tuomas 1/12 => Pakana .: Ihmisten oli korotettava, koska Hän oli rakkaus, Jumala
uskova => pikkulotta: sefu paikalla
Ex-pertti liittyy keskusteluun. Hän on chattäillyt 5 minuutin ajan..
Tuomas 1/12 => Pakana .: Hän alansi itsensä, vaikka tiesi olevansa Jumala
Finlandia: Ei uskalla Simppa tulla takaisin
pikkulotta poistuu paikalta: kattoo äiti teresaa......
Victoria777: Terapia: Helvetti takana
Uskonveli. => Ex-pertti: hauska nikki sulla
adsl-m poistui keskustelusta
Tuomas 1/12 => Pakana .: Muuten ei olisi ollut esimerkkikään meille
infernum: onpas broidilla surkeita biiseijä koneel
Victoria777: Menen nyt tullakseni taas takaisin.
Victoria777 poistui keskustelusta
Vastaukset 1
Vanhimmat
Lämminhenkistä ja syvällistä pohdintaa elämän peruskysymyksistä.
Tämä keskustelunpätkä pätkä kertoo ilahduttavasti, että kirkkochatin ovet ovat kaikille avoinna ja aika monenlaista väkeä siellä ramppaakin.